//This file solves and simulates a slightly augmented RBC model.

var n y c k x eta_b eta_a eta_x;

varexo eps_b eps_a eps_x;

parameters A theta delta beta rho_b rho_a rho_x ;

A=2.3;
theta=0.36;
delta=0.025;
beta=0.99;
rho_b=0.5;
rho_a=0.5;
rho_x=0.5;


model(linear);
# y_k = (1/theta)*(1/beta-1+delta);
# c_k = y_k-delta;
n=y-c;
c=-eta_b(+1)+eta_b+(1-delta)*beta*eta_x(+1)-eta_x+c(+1)-theta*beta*y_k*y(+1)+theta*beta*y_k*k;
y=eta_a+theta*k(-1)+(1-theta)*n;
k=delta*x+(1-delta)*k(-1)+delta*eta_x;
x=(y_k/delta)*y-(c_k/delta)*c;
eta_b=rho_b*eta_b(-1)+eps_b;
eta_a=rho_a*eta_a(-1)+eps_a;
eta_x=rho_x*eta_x(-1)+eps_x;
end;

shocks;
var eps_b; stderr 0.02;
var eps_a; stderr 0.02;
var eps_x; stderr 0.02;
end;

three_shock_steadystate;

steady;

check;
stoch_simul(periods=3000, irf=20);
datatomfile('simuldata',[])
